@@ -3,10 +3,10 @@ from typing import Union, Callable, Any
 from .base import DataFrame
 
 __all__ = (
-    'BusRoutes',
+    'BusRoute',
 )
 
-class BusRoutes:
+class BusRoute:
     def __init__(self, **kwargs):
         operator_map = {"SBST": "SBS Transit",
                         "SMRT": "SMRT Corporation",
